@@ -1,4 +1,4 @@
-/*  $Id: FrenchVerbDictionary.h,v 1.43 2011/01/25 02:29:44 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.h,v 1.45 2012/11/18 19:56:06 sarrazip Exp $
     FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef _H_FrenchVerbDictionary
@@ -51,8 +51,19 @@ public:
 
     enum Language { NO_LANGUAGE, FRENCH, ITALIAN, GREEK };
 
+    /** Returns the language identifier recognized in the given string.
+        @param  twoLetterCode           string containing a language code
+        @returns                        a member of the 'Language' enum,
+                                        or NO_LANGUAGE if the string was
+                                        not recognized
+    */
     static Language parseLanguageCode(const std::string &twoLetterCode);
 
+    /** Returns the two-letter code that names the given language identifier.
+        @param  l               valid language identifier
+        @returns                empty string if 'l' is NO_LANGUAGE or invalid,
+                                or a twi-letter string otherwise
+    */
     static std::string getLanguageCode(Language l);
 
     /** Returns the full path names of the conjugation and verb XML files
