@@ -1,4 +1,4 @@
-/*  $Id: c-api.h,v 1.11 2010/07/04 05:49:51 sarrazip Exp $
+/*  $Id: c-api.h,v 1.14 2012/11/18 19:56:06 sarrazip Exp $
     FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef _H_c_api
@@ -41,6 +41,18 @@ typedef enum
     VERBISTE_IMPERATIVE_MODE,
     VERBISTE_PARTICIPLE_MODE,
     VERBISTE_GERUND_MODE,
+
+    // Greek modes:
+    VERBISTE_PRESENT_INDICATIVE,
+    VERBISTE_PRESENT_SUBJUNCTIVE,
+    VERBISTE_PRESENT_IMPERATIVE,
+    VERBISTE_PRESENT_GERUND,
+    VERBISTE_PAST_IMPERFECT_INDICATIVE,
+    VERBISTE_PAST_PERFECT_INDICATIVE,
+    VERBISTE_PAST_PERFECT_SUBJUNCTIVE,
+    VERBISTE_PAST_PERFECT_IMPERATIVE,
+    VERBISTE_PAST_PERFECT_INFINITIVE
+
 /** Valid conjugation modes. */
 } Verbiste_Mode;
 
@@ -50,7 +62,12 @@ typedef enum
     VERBISTE_PRESENT_TENSE,
     VERBISTE_PAST_TENSE,
     VERBISTE_IMPERFECT_TENSE,
-    VERBISTE_FUTURE_TENSE
+    VERBISTE_FUTURE_TENSE,
+    VERBISTE_ACTIVE_TENSE,
+    VERBISTE_PASSIVE_TENSE,
+    VERBISTE_IMPERATIVE_ACTIVE_TENSE,
+    VERBISTE_IMPERATIVE_PASSIVE_TENSE,
+    VERBISTE_PAST_PERFECT
 
 /** Valid conjugation tenses. */
 } Verbiste_Tense;
@@ -136,45 +153,6 @@ const char *verbiste_get_init_error();
 int verbiste_close(void);
 
 
-/** Converts a Latin-1 string to lower-case.
-    @param        latin1_string        ISO-8859-1 character string to be converted;
-                                if NULL, the function returns NULL
-    @returns                        lower-case version of the character string;
-                                the returned pointer designates a dynamically
-                                allocated, '\0'-terminated string which must
-                                be freed by a call to verbiste_free_string().
-*/
-char *verbiste_tolower_latin1(const char *latin1_string);
-
-
-/** Converts a Latin-1 string into UTF-8.
-    @param        latin1_string        ISO-8859-1 character string to be converted;
-                                if NULL, the function returns NULL
-    @returns                        a UTF-8 version of the character string,
-                                or NULL if an error occurs (there is
-                                current no way with this API to determine
-                                the cause of the error);
-                                the returned pointer designates a dynamically
-                                allocated, '\0'-terminated string which must
-                                be freed by a call to verbiste_free_string().
-*/
-char *verbiste_latin1_to_utf8(const char *latin1_string);
-
-
-/** Converts a UTF-8 string into Latin-1.
-    @param        utf8_string   UTF-8 character string to be converted;
-                                if NULL, the function returns NULL
-    @returns                    an ISO-8859-1 version of the character string,
-                                or NULL if an error occurs (there is
-                                current no way with this API to determine
-                                the cause of the error);
-                                the returned pointer designates a dynamically
-                                allocated, '\0'-terminated string which must
-                                be freed by a call to verbiste_free_string().
-*/
-char *verbiste_utf8_to_latin1(const char *utf8String);
-
-
 /** Frees the memory associated with the given string.
     The string to deallocate must have been received from a function
     of this API that specifically requires the deallocation to be
